marktools.attach_annotations_to_components_in_expr
==================================================

.. autofunction:: abjad.tools.marktools.attach_annotations_to_components_in_expr.attach_annotations_to_components_in_expr
